==> v0.1.1.tar.gz: gterm/cmd/gterm/main.go <==
package main

import (
	"flag"
	"fmt"
	"net/http"
	"os"

	"kumoly.io/lib/klog"
	"kumoly.io/lib/ksrv"
	"kumoly.io/tools/gterm"
)

var Version = "0.0.0"
var Build = "alpha"

var (
	flagAllowIP  string
	flagAppName  string = "gterm"
	flagAddr     string
	flagShell    string
	flagLogLevel int
	flagDev      bool
	flagVer      bool
)

func init() {
	flag.StringVar(&flagAppName, "name", "gterm", "the application title")
	flag.StringVar(&flagAddr, "addr", ":8000", "address to bind")
	flag.StringVar(&flagShell, "shell", "bash", "the shell behind")
	flag.BoolVar(&flagDev, "dev", false, "is development mode")
	flag.IntVar(&flagLogLevel, "log-level", 9, "log level")
	flag.StringVar(&flagAllowIP, "allow", "", "restrict ip")
	flag.BoolVar(&flagVer, "v", false, "show version")

	flag.Usage = func() {
		fmt.Fprintf(os.Stderr, "Usage: gterm [options]\n")
		flag.PrintDefaults()
	}
}

func main() {
	flag.Parse()
	if flagVer {
		fmt.Printf("%v - %v\n", Version, Build)
		return
	}

	klog.LEVEL = klog.Llevel(flagLogLevel)
	klog.PROD = !flagDev

	g := gterm.New()
	g.AppName = flagAppName
	g.Cmd = flagShell

	server := &http.Server{
		Addr:    flagAddr,
		Handler: Middleware(g),
	}
	server.ListenAndServe()
}

func Middleware(next http.Handler) http.Handler {
	log := klog.Sub(flagAppName)
	return http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {
		defer func() {
			if err := recover(); err != nil {
				log.Error(err)
			}
		}()
		if flagAllowIP != "" {
			if !ksrv.MatchIPGlob(ksrv.GetIP(r), flagAllowIP) {
				w.WriteHeader(http.StatusForbidden)
				w.Write([]byte("permission denied"))
			}
		}
		next.ServeHTTP(w, r)
	})
}

==> v0.1.3.tar.gz: gterm/cmd/gterm/main.go <==
package main

import (
	"flag"
	"fmt"
	"net/http"
	"os"
	"strings"

	"kumoly.io/lib/klog"
	"kumoly.io/lib/ksrv"
	"kumoly.io/tools/gterm"
)

type arrayFlags []string

func (i *arrayFlags) String() string {
	return strings.Join(*i, ", ")
}

func (i *arrayFlags) Set(value string) error {
	*i = append(*i, strings.TrimSpace(value))
	return nil
}

var Version = "0.0.0"
var Build = "alpha"

var (
	flagAllowIP  string
	flagAppName  string
	flagAddr     string
	flagShell    string
	flagLogLevel int
	flagDev      bool
	flagVer      bool
	flagArgs     arrayFlags
	flagProfile  bool
)

func init() {
	flag.StringVar(&flagAppName, "name", "gterm", "the application title")
	flag.StringVar(&flagAddr, "addr", ":8000", "address to bind")
	flag.StringVar(&flagShell, "shell", "bash", "the shell behind")
	flag.Var(&flagArgs, "arg", "additional args to pass to cmd")
	flag.BoolVar(&flagDev, "dev", false, "is development mode")
	flag.IntVar(&flagLogLevel, "log-level", 9, "log level")
	flag.StringVar(&flagAllowIP, "allow", "", "restrict ip")
	flag.BoolVar(&flagProfile, "profile", false, "print default profile, invoked with <(..)")
	flag.BoolVar(&flagVer, "v", false, "show version")

	flag.Usage = func() {
		fmt.Fprintf(os.Stderr, "Usage: gterm [options] [args...]\n")
		flag.PrintDefaults()
	}
}

func main() {
	flag.Parse()
	if flagVer {
		fmt.Printf("%v - %v\n", Version, Build)
		return
	}
	if flagProfile {
		fmt.Println(gterm.BashProfile)
		return
	}

	klog.LEVEL = klog.Llevel(flagLogLevel)
	klog.PROD = !flagDev

	g := gterm.New()
	g.AppName = flagAppName
	g.Cmd = flagShell
	g.Args = flagArgs
	fmt.Println(flagArgs.String())

	server := &http.Server{
		Addr:    flagAddr,
		Handler: Middleware(g),
	}
	klog.Info("gterm starting at ", flagAddr)
	err := server.ListenAndServe()
	if err != nil {
		panic(err)
	}
}

func Middleware(next http.Handler) http.Handler {
	log := klog.Sub(flagAppName)
	return http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {
		defer func() {
			if err := recover(); err != nil {
				log.Error(err)
			}
		}()
		ip := ksrv.GetIP(r)
		if flagAllowIP != "" {
			if !ksrv.MatchIPGlob(ip, flagAllowIP) {
				w.WriteHeader(http.StatusForbidden)
				w.Write([]byte("permission denied"))
			}
		}
		next.ServeHTTP(w, r)
		log.Debug(ip, " ", r.URL.String())
	})
}
